@@ -3,15 +3,16 @@
 from __future__ import unicode_literals
 import sys
 import os
+import doctest
+import six
+
+import execjs
 
 if sys.version_info < (2, 7):
     import unittest2 as unittest
 else:
     import unittest
 
-import doctest
-import execjs
-
 
 class RuntimeTestBase:
     def test_context_call(self):
@@ -24,7 +25,7 @@ class RuntimeTestBase:
 
     def test_context_call_missing_function(self):
         context = self.runtime.compile("")
-        with self.assertRaises(execjs.ProgramError):
+        with self.assertRaises(execjs.Error):
             context.call("missing")
 
     def test_exec(self):
@@ -74,11 +75,11 @@ class RuntimeTestBase:
         self.assertTrue(self.runtime.exec_(code))
 
     def test_syntax_error(self):
-        with self.assertRaises(execjs.RuntimeError):
+        with self.assertRaises(execjs.Error):
             self.runtime.exec_(")")
 
     def test_thrown_exception(self):
-        with self.assertRaises(execjs.ProgramError):
+        with self.assertRaises(execjs.Error):
             self.runtime.exec_("throw 'hello'")
 
     def test_broken_substitutions(self):
@@ -90,18 +91,17 @@ class DefaultRuntimeTest(unittest.TestCase, RuntimeTestBase):
     def setUp(self):
         self.runtime = execjs
 
+class NodeRuntimeTest(unittest.TestCase, RuntimeTestBase):
+    def setUp(self):
+        self.runtime = execjs.get('Node')
 
-for name, runtime in execjs.available_runtimes().items():
-    class_name = name.capitalize() + "RuntimeTest"
-
-    def f(runtime=runtime):
-        class RuntimeTest(unittest.TestCase, RuntimeTestBase):
-            def setUp(self):
-                self.runtime = runtime
-        RuntimeTest.__name__ = str(class_name)  # 2.x compatibility
-        return RuntimeTest
-    exec("{class_name} = f()".format(class_name=class_name))
+class NashornRuntimeTest(unittest.TestCase, RuntimeTestBase):
+    def setUp(self):
+        self.runtime = execjs.get('Nashorn')
 
+class PhantomJSRuntimeTest(unittest.TestCase, RuntimeTestBase):
+    def setUp(self):
+        self.runtime = execjs.get('PhantomJS')
 
 class CommonTest(unittest.TestCase):
     def test_empty_path_environ(self):
@@ -126,9 +126,14 @@ class CommonTest(unittest.TestCase):
         r = execjs.ExternalRuntime("success", ["python"], "")
         self.assertTrue(r.is_available())
 
+    def test_attributes_export(self):
+        for name in execjs.__all__:
+            self.assertTrue(hasattr(execjs, name), "{} is not defined".format(name))
+
 
 def load_tests(loader, tests, ignore):
-    tests.addTests(doctest.DocTestSuite(execjs))
+    if six.PY3:
+        tests.addTests(doctest.DocTestSuite(execjs))
     return tests
 
 
